@@ -14,11 +14,14 @@ from identitylib.photo_client.model.bad_request import BadRequest
 from identitylib.photo_client.model.forbidden import Forbidden
 from identitylib.photo_client.model.internal_server_error import InternalServerError
 from identitylib.photo_client.model.not_found import NotFound
+from identitylib.photo_client.model.paginated_v1_beta1_photo_identifier_summary_list import PaginatedV1Beta1PhotoIdentifierSummaryList
 from identitylib.photo_client.model.paginated_v1_beta1_photo_list import PaginatedV1Beta1PhotoList
+from identitylib.photo_client.model.patched_v1_beta1_photo_identifier_summary_request import PatchedV1Beta1PhotoIdentifierSummaryRequest
 from identitylib.photo_client.model.permissions import Permissions
+from identitylib.photo_client.model.photo_identifier import PhotoIdentifier
 from identitylib.photo_client.model.scheme_enum import SchemeEnum
 from identitylib.photo_client.model.status_enum import StatusEnum
 from identitylib.photo_client.model.transient_image_url import TransientImageUrl
 from identitylib.photo_client.model.unauthorized import Unauthorized
 from identitylib.photo_client.model.v1_beta1_photo import V1Beta1Photo
-from identitylib.photo_client.model.v1_beta1_photo_identifier import V1Beta1PhotoIdentifier
+from identitylib.photo_client.model.v1_beta1_photo_identifier_summary import V1Beta1PhotoIdentifierSummary
