@@ -9,47 +9,46 @@ from identitylib.card_client import ApiClient
 from identitylib.card_client.api.v1beta1_api import V1beta1Api as CardApi
 
 
-responses = Responses('requests.packages.urllib3')
+responses = Responses("requests.packages.urllib3")
 
 
 class TestApiClientConfigurationMixin(TestCase):
-
     @responses.activate
     def test_access_token_is_fetched(self):
-        """ check the mixin requests an access token """
+        """check the mixin requests an access token"""
+
         def token_callback(request):
             self.assertEqual(
-                request.headers.get('Authorization'),
-                f'Basic {b64encode(b"client_key_test:client_secret_test").decode("utf-8")}'
+                request.headers.get("Authorization"),
+                f'Basic {b64encode(b"client_key_test:client_secret_test").decode("utf-8")}',
             )
             return 201, {}, '{"access_token": "test_access_token"}'
 
         # mock the response from the token endpoint
-        responses.add_callback('POST', '/oauth2/v1/token', token_callback)
+        responses.add_callback("POST", "/oauth2/v1/token", token_callback)
 
         # mock a successful request for the available barcodes
         def available_barcodes_callback(request):
-            self.assertEqual(request.headers.get('Authorization'), 'Bearer test_access_token')
+            self.assertEqual(request.headers.get("Authorization"), "Bearer test_access_token")
             return 200, {}, '{"results": []}'
+
         responses.add_callback(
-            'GET',
-            '/card/v1beta1/available-barcodes',
-            available_barcodes_callback
+            "GET", "/card/v1beta1/available-barcodes", available_barcodes_callback
         )
 
-        configuration = CardClientConfiguration('client_key_test', 'client_secret_test')
+        configuration = CardClientConfiguration("client_key_test", "client_secret_test")
         card_api_instance = CardApi(ApiClient(configuration))
 
         card_api_instance.v1beta1_available_barcodes_list()
 
     @responses.activate
     def test_refresh_access_token_fails(self):
-        """ check the mixin correctly raises exception when server responds 401 """
+        """check the mixin correctly raises exception when server responds 401"""
 
         # mock a 401 response code for the token
-        responses.add('POST', '/oauth2/v1/token', status=401)
+        responses.add("POST", "/oauth2/v1/token", status=401)
 
-        configuration = CardClientConfiguration('client_key', 'client_secret')
+        configuration = CardClientConfiguration("client_key", "client_secret")
         card_api_instance = CardApi(ApiClient(configuration))
 
         with self.assertRaises(RuntimeError):
@@ -57,11 +56,11 @@ class TestApiClientConfigurationMixin(TestCase):
 
     @responses.activate
     def test_refresh_access_token_no_token(self):
-        """ check the mixin correctly raises exception when no access_token in response """
+        """check the mixin correctly raises exception when no access_token in response"""
 
-        responses.add('POST', '/oauth2/v1/token', body='{}')
+        responses.add("POST", "/oauth2/v1/token", body="{}")
 
-        configuration = CardClientConfiguration('client_key', 'client_secret')
+        configuration = CardClientConfiguration("client_key", "client_secret")
         card_api_instance = CardApi(ApiClient(configuration))
 
         with self.assertRaises(RuntimeError):
@@ -79,12 +78,12 @@ class TestApiClientConfigurationMixin(TestCase):
             # respond with no 'expires_in' which means we use the default of 1 minute
             return 200, {}, '{"access_token": "new_access_token"}'
 
-        responses.add_callback('POST', '/oauth2/v1/token', token_callback)
+        responses.add_callback("POST", "/oauth2/v1/token", token_callback)
 
         # mock a successful request for the available barcodes
-        responses.add('GET', '/card/v1beta1/available-barcodes', body='{"results": []}')
+        responses.add("GET", "/card/v1beta1/available-barcodes", body='{"results": []}')
 
-        configuration = CardClientConfiguration('client_key_test', 'client_secret_test')
+        configuration = CardClientConfiguration("client_key_test", "client_secret_test")
         card_api_instance = CardApi(ApiClient(configuration))
 
         now = datetime.now()
@@ -115,12 +114,12 @@ class TestApiClientConfigurationMixin(TestCase):
             # respond with an 'expires_in' which indicates the token expires in 10 minutes
             return 200, {}, '{"access_token": "test_access_token", "expires_in": 600}'
 
-        responses.add_callback('POST', '/oauth2/v1/token', token_callback)
+        responses.add_callback("POST", "/oauth2/v1/token", token_callback)
 
         # mock a successful request for the available barcodes
-        responses.add('GET', '/card/v1beta1/available-barcodes', body='{"results": []}')
+        responses.add("GET", "/card/v1beta1/available-barcodes", body='{"results": []}')
 
-        configuration = CardClientConfiguration('client_key_test', 'client_secret_test')
+        configuration = CardClientConfiguration("client_key_test", "client_secret_test")
 
         card_api_instance = CardApi(ApiClient(configuration))
 
